var modal = new Modal('#waiting');

var ClassMgr = {
	base: new BASE(),

	/**
	 * 分页大小
	 */
	pageSize: 10,

	/**
	 * 开课中当前分页
	 */
	pageNoOpen: 0,

	/**
	 * 结束当前分页
	 */
	pageNoClose: 0,

	/**
	 * 状态用于保存当前
	 */
	openedClassAllLoaded: false,

	openedClassList: new AdvancedList("#opening"),

	closedClassList: new AdvancedList("#closed"),

	/**
	 * 当前Tab标签：1表示开课中、2表示已结束
	 */
	currentTab: 1,

	/**
	 * 是否网络出错
	 */
	isNetworkError: false,

	/**
	 * 初始化数据
	 */
	initData: function() {
		var fnCreateTime = function(data, item) {
			item.firstElementChild.id = data.id;
			item.querySelector('.detail>h4').innerText = data.title;
			item.querySelector('.time').innerText = new Date(data.opentime).Format('yyyy-MM-dd hh:mm:ss');
			item.querySelector('.thumbnail').src = data.coverImg + "?imageView2/1/w/64/h/64";
			item.querySelector('.live').id = data.streamId;
			item.querySelector('.chat').id = data.groupId;
		}
		ClassMgr.openedClassList.setItemTemplate('#opening>li:first-child');
		ClassMgr.openedClassList.onCreateItem = fnCreateTime;

		ClassMgr.closedClassList.setItemTemplate('#closed>li:first-child');
		ClassMgr.closedClassList.onCreateItem = fnCreateTime;
	},

	/**
	 * 获取课堂
	 */
	getClassList: function() {
		var pageNo = 0;
		if(ClassMgr.currentTab == 1) {
			ClassMgr.pageNoOpen++;
			pageNo = ClassMgr.pageNoOpen;
		} else if(ClassMgr.currentTab == 2) {
			ClassMgr.pageNoClose++;
			pageNo = ClassMgr.pageNoClose;
		}

		mui.ajax(ClassMgr.base.getBASEURL() + "appapi/1/class/myClasses.do", {
			data: {
				classStatus: ClassMgr.currentTab,
				pageNo: pageNo,
				pageSize: ClassMgr.pageSize
			},
			type: "GET",
			success: function(response) {
				if(response.success) {
					if(ClassMgr.currentTab == 1) {
						ClassMgr.openedClassList.multipleAppend(response.obj.list);
					} else {
						ClassMgr.closedClassList.multipleAppend(response.obj.list);
					}
					if(response.obj.list.length > 0) {
						mui('#pullrefresh').pullRefresh().endPullupToRefresh(false); //有数据结束加载
					} else {
						if(ClassMgr.currentTab == 1) {
							ClassMgr.openedClassAllLoaded = true;
						}
						mui('#pullrefresh').pullRefresh().endPullupToRefresh(true); //无更多数据结束加载
					}
					mui('#pullrefresh').pullRefresh().endPulldownToRefresh(); //结束向下刷新
				} else {
					mui.toast(response.message);
				}
			},
			error: function(response) {
				mui.toast("网络出错：" + JSON.stringify(response));
				ClassMgr.isNetworkError = true;
			}
		});
	},

	/**
	 * 重新刷新数据
	 */
	resetOpeningClass: function() {
		mui('#pullrefresh').pullRefresh().refresh(true); //重置上拉加载
		ClassMgr.openedClassList.clearAll();
		ClassMgr.pageNoOpen = 0;
		ClassMgr.getClassList();
	},

	/**
	 * 重新刷新数据
	 */
	resetClosedClass: function() {
		mui('#pullrefresh').pullRefresh().refresh(true); //重置上拉加载
		ClassMgr.closedClassList.clearAll();
		ClassMgr.pageNoClose = 0;
		ClassMgr.getClassList();
	},

	/**
	 * 下拉刷新
	 */
	pulldownRefresh: function() {
		if(ClassMgr.isNetworkError) {
			setTimeout(function() {
				if(ClassMgr.currentTab == 1) {
					ClassMgr.resetOpeningClass();
				} else {
					classmg.resetClosedClass();
				}
				ClassMgr.isNetworkError = false;
			}, 800);
		} else {
			mui('#pullrefresh').pullRefresh().endPulldownToRefresh(); //refresh completed
		}
	},

	/**
	 * 上拉加载下一页
	 */
	pullupRefresh: function() {
		setTimeout(function() {
			ClassMgr.getClassList();
		}, 800);
	},

	/**
	 * 删除课堂
	 * 
	 * @param {Object} lesson
	 */
	removeLesson: function(lesson) {
		modal.show();
		var url = ClassMgr.base.getBASEURL() + " appapi/1/class/delete?classId=" + lesson.parentNode.parentNode.id;
		mui.ajax(url, {
			type: "POST",
			success: function(response) {
				modal.hide();
				if(response.success) {
					mui.toast('成功删除该课堂！');
				//	lesson.parentNode.parentNode.parentNode.removeChild(lesson.parentNode.parentNode);
					ClassMgr.removeListItem(lesson);
				} else {
					mui.toast(response.msg);
				}
			},
			error: function(response) {
				modal.hide();
				mui.toast("删除失败：" + JSON.stringify(response));
			}
		});
	},

	/**
	 * 关闭课堂
	 * 
	 * @param {Object} lesson
	 */
	closeLesson: function(lesson) {
		modal.show();
		var url = ClassMgr.base.getBASEURL() + " /appapi/1/class/finish?classId=" + lesson.parentNode.parentNode.id;
		mui.ajax(url, {
			type: "POST",
			success: function(response) {
				modal.hide();
				if(response.success) {
					mui.toast('已关闭该课堂！');
					ClassMgr.removeListItem(lesson);
					ClassMgr.resetClosedClass();
				} else mui.toast(response.msg);
			},
			error: function(response) {
				console.info(response);
				modal.hide();
				mui.toast("关闭失败：" + JSON.stringify(response));
			}
		});

	},

	/**
	 * 删除 LI 节点
	 * 
	 *  @param {Object} children 任意子孙节点
	 * 
	 */
	removeListItem: function(children) {
		var parent = children.parentNode;
		while(parent != null && parent.tagName.toUpperCase() != 'LI') {
			parent = parent.parentNode;
		}

		if(parent != null && parent.tagName.toUpperCase() == 'LI') {
			parent.parentNode.removeChild(parent);
		}
	}
};

(function($, doc) {
	//初始化MUI及下拉控件
	$.init({
		pullRefresh: {
			container: '#pullrefresh',
			down: {
				callback: ClassMgr.pulldownRefresh
			},
			up: {
				contentrefresh: '正在加载...',
				contentnomore: '没有更多数据了', //可选，请求完毕若没有更多数据时显示的提醒内容；
				callback: ClassMgr.pullupRefresh
			}
		}
	});

	/**
	 * 初始化数据
	 */
	ClassMgr.initData();
	//点击开课中
	doc.getElementById("btnToOpened").addEventListener('tap', function() {
		ClassMgr.currentTab = 1;
		if(!ClassMgr.openedClassAllLoaded) {
			mui('#pullrefresh').pullRefresh().refresh(true); //重置上拉加载
		}
		return false;
	});
	//点击已结束
	doc.getElementById("btnToClosed").addEventListener('tap', function() {
		ClassMgr.currentTab = 2;
		mui('#pullrefresh').pullRefresh().refresh(true); //重置上拉加载
		$('#pullrefresh').pullRefresh().pullupLoading();
		return false;
	});
	//删除
	mui('#pullrefresh').on('tap', '.delete', function(event) {
		mui.confirm(' ', "是否删除课堂", ['是', '否'], function(e) {
			if(e.index == 0) {
				ClassMgr.removeLesson(event.target);
			}
		});
		return false;
	});
	//关闭课堂
	mui('#item1').on('tap', '.edit', function(event) {
		mui.confirm(' ', "是否关闭课堂", ['是', '否'], function(e) {
			if(e.index == 0) {
				ClassMgr.closeLesson(event.target);
			}
		});
		return false;
	});
	//直播
	mui('#item1').on('tap', '.live', function() {
		var base = new BASE();
		var profile = localStorage.profile;
		var tokenId = eval(profile).tokenId;
		if(base.getRUMTIME()==2) confirm("live:" + this.parentNode.parentNode.id + ":" + this.id+":"+tokenId);
		else if(base.getRUMTIME() == 1) {
			var notiClass = plus.ios.importClass("NSNotificationCenter");
			notiClass.defaultCenter().postNotificationNameobject("live", this.parentNode.parentNode.id + ":" + this.id);
		} else mui.toast('请使用APP进行直播！');
	});
	//聊天
	mui('#pullrefresh').on('tap', '.chat', function() {
		openWindow('IM.html?classId=' + this.parentNode.parentNode.id);
		return false;
	});
	//回看
	mui('#item2').on('tap', '.live', function() {
		openWindow("live.html?classId=" + this.parentNode.parentNode.id+'&watchBack=1');
		return false;
	});
	//创建课堂
	doc.getElementById("btnCreate").addEventListener('tap', function() {
		openWindowInParent('DoctorMine_CreateClass.html');
		return false;
	});

	if($.os.plus) {
		$.plusReady(function() {
			setTimeout(function() {
				$('#pullrefresh').pullRefresh().pullupLoading();
			}, 500);
		});
	} else {
		$.ready(function() {
			$('#pullrefresh').pullRefresh().pullupLoading();
		});
	}

})(mui, document);