/**
 * 咨询师业务管理器
 */
var DoctorMgr = {

	base: new BASE(),

	pageSize: 10,

	pageNo: 0,

	doctorList: new AdvancedList("#doctorList"),

	/**
	 * 是否网络出错
	 */
	isNetworkError: false,

	/**
	 * 初始化数据
	 */
	initData: function() {
		DoctorMgr.doctorList.setItemTemplate('#doctorList>li:first-child');
		DoctorMgr.doctorList.onCreateItem = function(data, item) {
			var article = item.querySelector(".article");
			article.id = data.userId;
			article.name = data.userName;
			item.querySelector('.doctor-icon').setAttribute('src', data.userFace + "?imageView2/1/w/65/h/65");
			item.querySelector('.name').innerHTML = data.realName == null ? "佚名" : data.realName;
			item.querySelector('.title').innerHTML = data.attending;
		};
	},

	/**
	 * 获取咨询师列表
	 */
	getDoctorList: function() {

		DoctorMgr.pageNo++;

		mui.ajax(DoctorMgr.base.getBASEURL() + "appapi/1/doctor/list.do", {
			data: {
				pageNo: DoctorMgr.pageNo,
				pageSize: DoctorMgr.pageSize
			},
			type: "GET",
			success: function(response) {
				if(response.success) {
					DoctorMgr.doctorList.multipleAppend(response.obj.list);
					if(response.obj.list.length > 0) {
						mui('#pullrefresh').pullRefresh().endPullupToRefresh(false); //有数据结束加载
					} else {
						mui('#pullrefresh').pullRefresh().endPullupToRefresh(true); //无更多数据结束加载
					}
					mui('#pullrefresh').pullRefresh().endPulldownToRefresh(); //结束向下刷新
				} else {
					mui.toast(response.message);
				}
			},
			error: function(response) {
				mui.toast("网络出错：" + JSON.stringify(response));
				DoctorMgr.isNetworkError = true;
			}
		});
	},

	/**
	 * 重新刷新数据
	 */
	resetData: function() {
		mui('#pullrefresh').pullRefresh().refresh(true); //重置上拉加载
		DoctorMgr.doctorList.clearAll();
		DoctorMgr.pageNo = 0;
		DoctorMgr.getDoctorList();
	},

	pulldownRefresh: function() {
		if(DoctorMgr.isNetworkError) {
			setTimeout(function() {
				DoctorMgr.resetData();
				DoctorMgr.isNetworkError = false;
			}, 1500);
		} else {
			mui('#pullrefresh').pullRefresh().endPulldownToRefresh(); //refresh completed
		}
	},

	pullupRefresh: function() {
		setTimeout(function() {
			DoctorMgr.getDoctorList();
		}, 1500);
	}

};

(function($, doc) {
	$.init({
		pullRefresh: {
			container: '#pullrefresh',
			down: {
				callback: DoctorMgr.pulldownRefresh
			},
			up: {
				contentrefresh: '正在加载...',
				contentnomore: '没有更多数据了', //可选，请求完毕若没有更多数据时显示的提醒内容；
				callback: DoctorMgr.pullupRefresh
			}
		}
	});

	/**
	 * 初始化数据
	 */
	DoctorMgr.initData();

	if($.os.plus) {
		$.plusReady(function() {
			setTimeout(function() {
				$('#pullrefresh').pullRefresh().pullupLoading();
			}, 1000);
		});
	} else {
		$.ready(function() {
			$('#pullrefresh').pullRefresh().pullupLoading();
		});
	}

	mui('#doctorList').on('tap', 'li > a', function() {
		openWindowInParent('doctor_blog.html?userId=' + this.id);
		return false;
	});

	doc.getElementById("btnSearch").addEventListener('tap', function() {
		openWindowInParent('search.html');
		return false;
	});

})(mui, document);