function ChattingHistoryLoader(parameters) {
	PullDownLoader.call(this, parameters);
	var superUpdate = this.update;
	var superLoadNextPage = this.loadNextPage;
	var list;
	var waitingModal;
	var consultId;
	var userId;

	this.loadNextPage = function() {
		if(this.isCompleted()) {
			mui('#container').pullRefresh().endPulldownToRefresh();
			return;
		}
		superLoadNextPage.call(this);
	}

	this.previousLoading = function() {
		//	waitingModal = MUIPopover.waiting({
		//		text: '加载中...'
		//	});
		waitingModal = MUIPopover.waitingDefault({
			backgroundAlpha: 0
		});
	};

	this.afterLoading = function() {
		waitingModal.close();
		mui('#container').pullRefresh().endPulldownToRefresh();
		mui('#container').pullRefresh().endPullupToRefresh(this.isCompleted());
	};

	this.handleSuccess = function(response) {
		if(response.success) {
			if(response.obj.data.length <= 0) {
				mui.toast('没有更多数据');
				this.resetCompleted(true);
				return false;
			} else {
				return true;
			}
		} else {
			mui.toast(response.msg);
			return false;
		}
	};

	this.handleError = function(response) {
		mui.toast("网络连接失败！请重试！");
	};

	this.doRefresh = function(response) {
		var messageData = response.obj.data;
		var msgList = list;

		for(var i = 0; i < messageData.length; i++) {
			if(messageData[i].content) {
				var msgItem;
				if(userId == messageData[i].userId) {
					msgItem = msgList.sendMessage(msgList.createText(messageData[i].content));
				} else {
					msgItem = msgList.receivedMessage(msgList.createText(messageData[i].content));
				}
				msgList.appendItem(msgItem);
			}
		}
		return response.obj.data.length;
	};

	this.createRequestData = function() {
		var data = {
			consultId: consultId,
			pageNo: this.getNextPage(),
			pageSize: this.getPageSize()
		};
		return data;
	};

	this.reload = function() {
		this.resetHasLoaded();
		this.resetLoadingState(false);
		this.resetCompleted(false);

		this.loadNextPage();
	}

	this.update = function(parameters) {
		list = parameters.list;
		consultId = parameters.consultId;
		userId = parameters.userId;

		superUpdate.call(this, parameters);
	};

	this.update(parameters);
}

/**
 * 咨询师业务管理器
 */
var ChattingMsg = {
	base: new BASE(),
	msgList: new MessageList("#msgList"),
	args: GetRequest(),
	profile: eval(localStorage.profile),
	loader: null,

	/**
	 * 初始化数据
	 */
	initData: function() {
		this.msgList.setSendTemplate(document.querySelector("#template>li:last-child"));
		this.msgList.setReceivedTemplate(document.querySelector("#template>li:first-child"));
		this.msgList.clearAll = function() {
			while(this.container.childElementCount > 0) {
				this.container.removeChild(this.container.firstChild);
			}
		};

		this.loader = new ChattingHistoryLoader({
			requestUrl: this.base.getBASEURL() + "appapi/1/consult/talkHistory",
			pageSize: 20,
			list: this.msgList,
			userId: this.profile.userId,
			consultId: this.args.consultId
		});

		var titleHeight = document.querySelector('.mui-title').offsetHeight;
		document.querySelector('.mui-scroll-wrapper').style.height = (window.innerHeight - titleHeight) + 'px';
	},

	pulldownRefresh: function() {
		console.log(100);
		setTimeout(function() {
			//		mui('#container').pullRefresh().endPulldownToRefresh();
		}, 1500);
		ChattingMsg.loader.loadNextPage();
	},

	pullupRefresh: function() {
		console.log(101);
		ChattingMsg.loader.loadNextPage();
	},

	getUserInfo: function() {
		function initTemplate(userId, callback) {
			var url = ChattingMsg.base.getBASEURL() + 'appapi/1/user/profile';
			var data = {
				userId: userId,
			};
			mui.ajax(url, {
				data: data,
				success: function(response) {
					if(!response.success) {
						mui.toast(response.msg);
						return;
					} else {
						var data = response.obj;
						if(data.userId == ChattingMsg.profile.userId) {
							template.querySelector('li:last-child').querySelector('img').src = data.userFace;
							
						} else {
							template.querySelector('li:first-child').querySelector('img').src = data.userFace;
							document.querySelector('.user-name').innerHTML = data.realName ? data.realName : data.userName;
						}
					}

					if(callback) {
						callback(response);
					}
				},
				error: function(response) {
					mui.toast("网络异常，请退出重试!");
				}
			});
		}
		
		mui.ajax(
			ChattingMsg.base.getBASEURL() + 'appapi/1/consult/user', {
				data: {
					consultId: ChattingMsg.args.consultId
				},
				success: function(response) {
					var consultUserId = response.obj.consultUserId;
					var userId = response.obj.userId;

					initTemplate(consultUserId, function() {
						initTemplate(userId, function() {
							mui('#container').pullRefresh().pullupLoading();
						});
					});
				},
				error: function() {
					mui.toast('网络异常，退出重试');
				}
			}
		);
	}
};

(function($, doc) {

	$.init({
		pullRefresh: {
			container: '#container',
			down: {
				callback: ChattingMsg.pulldownRefresh
			},
			up: {
				contentrefresh: '正在加载...',
				contentnomore: '没有更多数据了', //可选，请求完毕若没有更多数据时显示的提醒内容；
				callback: ChattingMsg.pullupRefresh
			}
		}
	});

	/**
	 * 初始化数据
	 */
	ChattingMsg.initData();

	if($.os.plus) {
		$.plusReady(function() {
			setTimeout(function() {
				ChattingMsg.getUserInfo();
			}, 1000);
		});
	} else {
		$.ready(function() {
			ChattingMsg.getUserInfo();
		});
	}

})(mui, document);