/**
 * 多媒体管理器
 */
var MediaManager = {
	/**
	 * 七牛上传器
	 */
	qiniuUploader: null,
	/**
	 * 上传控件
	 */
	uploadCtrl: document.getElementById("txtUpload"),
	/**
	 * 已上传图片
	 */
	arrUploadedImg: [],
	/**
	 * 初始化七牛令牌
	 */
	initQiniuToken: function() {
		var token_url = new BASE().getBASEURL() + "appapi/1/qiniu/upload/token.do";
		mui.ajax(token_url, {
			success: function(response) {
				if(response.success) {
					MediaManager.initQiniu(response.msg);
				} else {
					mui.toast(response.msg);
				}
			},
			error: function(response) {
				console.info(response);
			}
		});
	},
	/**
	 * 初始化七牛
	 * 
	 * @param {Object} qiniuToken 七牛令牌
	 */
	initQiniu: function(qiniuToken) {
		MediaManager.qiniuUploader = Qiniu.uploader({
			runtimes: 'html5,flash,html4',
			browse_button: 'btnUpload',
			container: 'container',
			drop_element: 'container',
			max_file_size: '100mb',
			flash_swf_url: 'js/plupload/Moxie.swf',
			dragdrop: false,
			chunk_size: '4mb',
			uptoken: qiniuToken,
			multi_selection: false,
			unique_names: true, // 默认 false，key为文件名。若开启该选项，SDK为自动生成上传成功后的key（文件名）。
			domain: 'http://media.guohaozhongyi.com/',
			auto_start: true,
			init: {}
		});
		MediaManager.qiniuUploader.bind('FilesAdded', function(up, files) {
			var attachmentList = document.getElementById('attachmemtList');
			var count = attachmentList.childElementCount;
			var child = attachmentList.childNodes[count - 1];
			child.id = files[0].id;
			MediaManager.uploadCtrl.value = '';
			mui.toast('正在上传图片...请稍等');
		});
		MediaManager.qiniuUploader.bind('FileUploaded', function(up, file, info) {
			var attachmentList = document.getElementById('attachmemtList');
			var imgUrl = "http://media.guohaozhongyi.com/" + file.target_name;
			var count = attachmentList.childElementCount;
			attachmentList.childNodes[count - 1].childNodes[0].setAttribute('src', imgUrl);
			MediaManager.arrUploadedImg.push(imgUrl);
			mui.toast('图片上传完毕！请继续！');
		});
	},
	/**
	 * 上传
	 */
	upload: function() {
		var attachmentList = document.getElementById('attachmemtList');
		if(attachmentList.childElementCount > 2) {
			return mui.toast('图片最多只能有2个！');
		}
		MediaManager.uploadCtrl.click();
	},
	/**
	 * 上传文件
	 * 
	 */
	uploadFile: function() {
		var fileName = MediaManager.uploadCtrl.value.toLowerCase();
		if(fileName) {
			var attachmentList = document.getElementById('attachmemtList');
			if(attachmentList.childElementCount > 2) return mui.toast('只需上传身份证正反面！');
			var attachment = MediaManager.uploadCtrl.files[0];
			var li = document.createElement('li');
			li.setAttribute('onclick', 'MediaManager.show(this);');
			var imageReg = new RegExp("(.jpg|.png|.bmp|.jpeg)$");
			if(imageReg.test(fileName)) {
				var img = document.createElement('img');
				img.src = window.URL.createObjectURL(attachment);
				img.style.height = '100%';
				img.style.width = 'auto';
				li.appendChild(img);
			} else return mui.toast('不支持该文件类型');
			attachmentList.insertBefore(li, attachmentList.lastElementChild);
			MediaManager.qiniuUploader.addFile(MediaManager.uploadCtrl.files[0]);
		}
	},
	/**
	 * 显示多媒体
	 * 
	 * @param {Object} li 
	 */
	show: function(li) {
		var modal = new Modal('#show');
		var child = li.firstElementChild;
		modal.content.appendChild(child.cloneNode());
		modal.body.onclick = function() {
			modal.hide();
			modal.content.removeChild(modal.content.firstElementChild);
		};
		modal.body.querySelector('#delete').onclick = function() {
			MediaManager.removeImg(li.id);
			MediaManager.qiniuUploader.removeFile(MediaManager.qiniuUploader.getFile(li.id));
			li.remove();
		}.bind(li);
		modal.show();
		document.getElementById('show').style.top = "0";
		document.getElementById('show').querySelector('.content').style.width = "100%";
		document.getElementById('show').querySelector('.content').childNodes[0].style.width = "100%";
	},
	/**
	 * Clear Img
	 * 
	 * @param {Object} id
	 */
	removeImg: function(id) {
		var newArrImg = [];
		for(var i = 0; i < MediaManager.arrUploadedImg.length; i++) {
			if(MediaManager.arrUploadedImg[i].indexOf(id) == -1) {
				newArrImg.push(MediaManager.arrUploadedImg[i]);
			}
		}
		MediaManager.arrUploadedImg = newArrImg;
	}
};

/**
 * 地区管理器
 */
var AreaManager = {
	/**
	 *区域选择器 
	 */
	areaPicker: null,
	/**
	 * 省Id
	 */
	provinceId: 0,
	/**
	 * 市Id
	 */
	cityId: 0,
	/**
	 * 区县Id
	 */
	district: 0,
	/**
	 * 初始化地区
	 */
	initArea: function() {

		AreaManager.areaPicker = new mui.PopPicker({
			layer: 3
		});
		AreaManager.areaPicker.setData(_AreaJson); //_AreaJson在area.js中定义
	},

	/**
	 * 选择区域
	 */
	choose: function() {
		AreaManager.areaPicker.show(function(items) {
			AreaManager.provinceId = (items[0] || {}).value;
			AreaManager.cityId = items.length > 1 ? items[1].value : 0;
			AreaManager.districtId = items.length > 2 ? items[2].value : 0;;
			var html = items[0].text + " " + (items.length > 1 ? items[1].text : "") + " " +
				(items.length > 2 ? items[2].text : "");
			document.getElementById("district").value = html;
		});
	}

};

/**
 * 商城管理器
 */
var MallManager = {
	/**
	 * 基础库
	 */
	base: new BASE(),
	/**
	 * 商城令牌
	 */
	mallToken: '',
	/**
	 * 初始化商城令牌
	 */
	initMallToken: function() {
		var url = this.base.getBASEURL() + "appapi/1/user/getMallToken";
		mui.ajax(url, {
			data: {},
			type: "POST",
			success: function(response) {
				if(response.success) {
					MallManager.mallToken = response.msg;
				} else {
					mui.toast(response.msg);
				}
			},
			error: function(response) {
				mui.toast("网络出错：" + JSON.stringify(response));
			}
		});
	},
	/**
	 * 申请开店
	 */
	apply: function() {
		var store_name = document.getElementById("store_name").value;
		var district = document.getElementById("district").value;
		var addr = document.getElementById("addr").value;
		var zip = document.getElementById("zip").value;
		var member_name = document.getElementById("member_name").value;
		var tel = document.getElementById("tel").value;
		var bank_account_name = document.getElementById("bank_account_name").value;
		var bank_account_number = document.getElementById("bank_account_number").value;
		var id_number = document.getElementById("id_number").value;
		var pic = ""; //图片
		var pics = ""; //图片串
		if(!store_name) {
			mui.toast("店铺名称不能为空，请填写");
			return;
		}
		if(!district || AreaManager.provinceId == 0 || AreaManager.cityId == 0) {
			mui.toast("地区不能为空，请选择地区");
			return;
		}
		if(!addr) {
			mui.toast("详细地址不能为空，请填写");
			return;
		}
		if(!zip) {
			mui.toast("邮编不能为空，请填写");
		}
		if(!member_name) {
			mui.toast("真实姓名不能为空，请填写");
			return;
		}
		if(!tel) {
			mui.toast("联系电话不能为空，请填写");
			return;
		}
		if(!bank_account_name) {
			mui.toast("银行开户名不能为空，请填写");
			return;
		}
		if(!bank_account_number) {
			mui.toast("银行账号不能为空，请填写");
			return;
		}
		if(!id_number) {
			mui.toast("身份证不能为空，请填写");
			return;
		}
		if(MediaManager.arrUploadedImg.length < 2) {
			mui.toast("请上传身份证正面及反面两张图片");
			return;
		}
		mui.ajax(this.base.getMallUrl() + "api/apply.do", {
			data: {
				tk: MallManager.mallToken,
				store_name: store_name,
				attr: addr,
				zip: zip,
				member_name: member_name,
				tel: tel,
				bank_account_name: bank_account_name,
				bank_account_number: bank_account_number,
				store_provinceid: AreaManager.provinceId,
				store_cityid: AreaManager.cityId,
				store_regionid: AreaManager.districtId,
				bank_provinceid: AreaManager.provinceId,
				bank_cityid: AreaManager.cityId,
				bank_regionid: AreaManager.districtId,
				id_number: id_number,
				id_img: MediaManager.arrUploadedImg[0],
				pics: MediaManager.arrUploadedImg.join('|')
			},
			type: "POST",
			success: function(response) {
				if(response.result == 1) {
					mui.toast(response.message);
					setTimeout(function() {
						location.href = 'home.html#mine';
					}, 2000);
				} else {
					mui.toast(response.message);
				}
			},
			error: function(response) {
				mui.toast("网络出错：" + JSON.stringify(response));
			}
		});
	}
};

/**
 * 初始化视图
 */
function initView() {

	//地区选择框点击事件监听
	document.getElementById("district").addEventListener('tap', function() {
		AreaManager.choose();
	});

	//上传图标点击事件监听
	document.getElementById("btnAdd").addEventListener('tap', function() {
		MediaManager.upload();
	});
	//上传控件内容变化事件监听
	document.getElementById("txtUpload").addEventListener('change', function() {
		MediaManager.uploadFile();
	});

	//申请按钮点击事件
	document.getElementById("btnApply").addEventListener("tap", function() {
		MallManager.apply();
	});
}

/**
 * 初始化数据
 */
function initData() {
	//初始化七牛上传
	MediaManager.initQiniuToken();
	//初始化商城令牌
	MallManager.initMallToken();
	//初始化地区选择数据
	AreaManager.initArea();
}

(function($, doc) {
	$.init();
	$.ready(function() {
		//初始化视图
		initView();
		//初始化数据
		initData();

	});
})(mui, document);