/**
 * 通用遮罩
 */
function MUIPopover() {
	var modal = false;
	var domBk;
	var popup = this;

	/**
	 * domContent:内容dom
	 * backgroundAlpha:背景透明度
	 */
	this.popover = function(parameters) {
		var domContent = parameters.domContent;
		var backgroundAlpha = parameters.backgroundAlpha;

		mask.show();

		var domMask = document.querySelector('.mui-backdrop');
		domMask.style.background = 'rgba(0,0,0,' + (backgroundAlpha ? backgroundAlpha : 0.9) + ')';
		domMask.style.overflow = 'scroll';

		if(domContent) domMask.appendChild(domContent);

		domMask.addEventListener('tap', function(e) {
			if(e.target instanceof HTMLVideoElement || e.target instanceof HTMLAudioElement) {
				e.preventDefault();
				e.stopPropagation();
			}
		}, true);

		modal = false;
	}

	/**
	 * 关闭modal
	 */
	this.close = function() {
		if(modal && domBk) {
			document.getElementsByTagName('body')[0].removeChild(domBk);
			domBk = null;
			modal = false;
			return;
		}
		var domMask = document.querySelector('.mui-backdrop');
		if(domMask) {
			while(domMask.childNodes.length > 0) {
				domMask.removeChild(domMask.childNodes[0]);
			}
		}
	}

	/**
	 * 弹出modal
	 * domContent:***
	 * closeHandler:关闭按钮回调
	 * recycleHandler:删除按钮回调
	 * downloadHandler:下载按钮回调
	 * backgroundAlpha:透明度
	 * 
	 * 回调参数MUIPopover Object：
	 * closeHandler(popup){popup.close();};
	 */
	this.doModal = function(parameters) {
		var domContent = parameters.domContent;
		var fxClose = parameters.closeHandler;
		var fxRecycle = parameters.recycleHandler;
		var fxDownload = parameters.downloadHandler;
		var backgroundAlpha = parameters.backgroundAlpha;

		var bk = document.createElement('div');

		bk.style.background = 'rgba(0,0,0,' + (backgroundAlpha != undefined ? backgroundAlpha : 0.5) + ')';
		bk.style.position = 'fixed';
		bk.style.width = document.getElementsByTagName('body')[0].scrollWidth + 'px';
		bk.style.height = document.getElementsByTagName('body')[0].scrollHeight + 'px';
		bk.style.zIndex = 1000;
		bk.style.top = 0;

		var close;
		if(fxClose) {
			close = document.createElement('div');
			close.classList.add('pop-close');
			close.addEventListener('click', function() {
				fxClose(popup);
			});
		}

		var download;
		if(fxDownload) {
			download = document.createElement('div');
			download.classList.add('pop-download');
			download.addEventListener('click', function() {
				fxDownload(popup);
			});
		}

		var recycle;
		if(fxRecycle) {
			recycle = document.createElement('div');
			recycle.classList.add('pop-recycle');
			recycle.addEventListener('click', function() {
				fxRecycle(popup);
			});
		}

		if(close)
			bk.appendChild(close);
		if(recycle)
			bk.appendChild(recycle);
		if(download)
			bk.appendChild(download);

		if(domContent) {
			bk.appendChild(domContent);
			domBk = bk;
			document.getElementsByTagName('body')[0].appendChild(bk);
		}

		if(download) {
			download.style.left = (window.innerWidth - download.offsetWidth) / 2 + "px";
			download.style.top = (window.innerHeight - (download.offsetHeight + 10)) + 'px';
		}

		if(recycle) {
			recycle.style.left = (window.innerWidth - recycle.offsetWidth) / 2 + "px";
			recycle.style.top = (window.innerHeight - ((download ? download.offsetHeight + recycle.offsetHeight : recycle.offsetHeight) + 10)) + 'px';
		}

		modal = true;
	}

	var mask = mui.createMask(this.close);
}

MUIPopover.createDefaultLoadingTemplate = function() {
	var mask = document.createElement('div');
	mask.classList.add('default-modal');

	mask.innerHTML = "<div class=\"content\">" +
		"<i class=\"iconfont icon-loading\"></i>" +
		"<p>获取中...</p></div></div>";

	return mask;
}

MUIPopover.createLoadingTemplate = function(text) {
	var mask = document.createElement('div');
	mask.classList.add('mlu7');
	mask.innerHTML =
		"<div class=\"mul7circ m7c1\"></div>" +
		"<div class=\"mul7circ m7c2\"></div>" +
		"<div class=\"mul7circ m7c3\"></div>" +
		"<div class=\"mul7circ m7c4\"></div>" +
		"<div class=\"mul7circ m7c5\"></div>" +
		"<div class=\"mul7circ m7c6\"></div>" +
		"<div class=\"mul7circ m7c7\"></div>" +
		"<div class=\"mul7circ m7c8\"></div>" +
		"<div class=\"mul7circ m7c9\"></div>" +
		"<div class=\"mul7circ m7c10\"></div>" +
		"<div class=\"mul7circ m7c11\"></div>" +
		"<div class=\"mul7circ m7c12\"></div>";

	var wrapper = document.createElement('div');
	var span = document.createElement('span');
	span.classList.add('waiting-text');
	span.innerText = text ? text : 'loading...';

	wrapper.appendChild(mask);
	wrapper.appendChild(span);

	var height = window.innerHeight;
	var width = window.innerWidth;
	var top = (height - 70) / 2;
	var left = (width - 70) / 2;
	wrapper.style.top = top + 'px';
	wrapper.style.left = left + 'px';
	wrapper.style.position = 'absolute';

	return wrapper;
}

/**
 * domContent:内容dom
 * backgroundAlpha:背景透明度
 */
MUIPopover.popover = function(parameters) {
	var domContent = parameters.domContent;
	var backgroundAlpha = parameters.backgroundAlpha;
	var popup = new MUIPopover();
	popup.popover({
		domContent: domContent,
		backgroundAlpha: backgroundAlpha
	});
	return popup;
}

/**
 * 自动检索显示图片，视音频，回调函数不为空转为Modal形式
 * @param {Object} parameters
 */
MUIPopover.autoPopover = function(parameters) {
	var domSource = parameters.domSource;
	var top = parameters.top;
	var backgroundAlpha = parameters.backgroundAlpha;
	var closeHandler = parameters.closeHandler;
	var recycleHandler = parameters.recycleHandler;
	var downloadHandler = parameters.downloadHandler;

	var filter = ['img', 'audio', 'video'];
	var type = [HTMLImageElement, HTMLVideoElement, HTMLAudioElement];
	var srcElement;

	for(var i = 0; i < filter.length; ++i) {
		if(srcElement) {
			break;
		}
		srcElement = domSource.querySelector(filter[i]);
		if(!srcElement) {
			for(var j = 0; j < type.length; ++j) {
				if(domSource instanceof type[j]) {
					srcElement = domSource;
					break;
				} else {
					if(domSource instanceof type[j]) {
						srcElement = domSource;
						break;
					}
				}
			}
		}
	}

	if(srcElement) {
		var wrapper = document.createElement('div');
		wrapper.style.width = '100%';
		wrapper.style.height = '100%';
		wrapper.style.textAlign = 'center';
		wrapper.style.lineHeight = window.innerHeight + 'px';

		srcElement = srcElement.cloneNode(true);
		if(srcElement instanceof HTMLVideoElement || srcElement instanceof HTMLAudioElement) {
			srcElement.setAttribute('controls', 'controls');
			srcElement.setAttribute('autoplay', 'autoplay');
		}
		wrapper.appendChild(srcElement);

		var maxContentHeight = window.innerHeight - ((32 + 16 + 16) + (32 + 10 + 16));
		srcElement.style.removeProperty('height');
		srcElement.style.marginTop = (top ? top : (32 + 16 + 16)) + "px";
		srcElement.style.maxWidth = '100%';
		srcElement.style.maxHeight = maxContentHeight + 'px';

		if(closeHandler || recycleHandler || downloadHandler) {
			var modal = new MUIPopover();
			modal.doModal({
				domContent: wrapper,
				closeHandler: closeHandler,
				recycleHandler: recycleHandler,
				downloadHandler: downloadHandler,
				backgroundAlpha: backgroundAlpha
			});

			return modal;
		} else {
			var popup = new MUIPopover();
			popup.popover({
				domContent: wrapper,
				backgroundAlpha: backgroundAlpha
			});

			return popup;
		}
	}
}

/**
 * css等待Modal
 * @param {Object} 
 * text
 * backgroundAlpha
 */
MUIPopover.waiting = function(parameters) {
	var text = parameters.text;
	var backgroundAlpha = parameters.backgroundAlpha;
	var modal = new MUIPopover();
	var template = MUIPopover.createLoadingTemplate(text);

	modal.doModal({
		domContent: template,
		fxClose: null,
		fxRecycle: null,
		fxDownload: backgroundAlpha
	});
	return modal;
}

/**
 * 默认
 * @param {Object} parameters
 */
MUIPopover.waitingDefault = function(parameters) {

	var backgroundAlpha = parameters.backgroundAlpha;
	var modal = new MUIPopover();
	var template = MUIPopover.createDefaultLoadingTemplate();

	modal.doModal({
		domContent: template,
		fxClose: null,
		fxRecycle: null,
		fxDownload: null,
		backgroundAlpha: backgroundAlpha
	});
	return modal;
}

/**
 * 微信分享操作提示
 */
MUIPopover.wxShareGuideTip = function(parameters) {
	function ElBlock(domObject, x, y, xOffset, yOffset, width, height) {
		this.domObject = domObject;
		domObject.style.visibility = 'hidden';
		this.x = x ? x : 0;
		this.y = y ? y : 0;
		this.xOffset = xOffset ? xOffset : 0;
		this.yOffset = yOffset ? yOffset : 0;
		this.width = width;
		this.height = height;
	}

	var textColor = 'white';
	var fontSize = 24;
	var backgroundAlpha = 0.68;
	var text = '';
	var blocks = [];

	if(parameters != undefined) {
		if(parameters.backgroundAlpha != undefined) {
			backgroundAlpha = parameters.backgroundAlpha;
		}
		if(parameters.textColor != undefined) {
			textColor = parameters.textColor;
		}
		if(parameters.fontSize != undefined) {
			fontSize = parameters.fontSize;
		}
		if(parameters.text != undefined) {
			text = parameters.text;
		}
		if(parameters.imgs != undefined) {
			var imgs = parameters.imgs;
			for(var i in imgs) {
				var imgWrapper = document.createElement('div');
				var img = document.createElement('img');
				img.setAttribute('src', imgs[i].src);
				if(imgs[i].width) {
					img.style.width = '100%';
				}
				if(imgs[i].height) {
					img.style.height = '100%';
				}
				imgWrapper.appendChild(img);
				blocks.push(new ElBlock(imgWrapper, imgs[i].x, imgs[i].y, imgs[i].xOffset, imgs[i].yOffset, imgs[i].width, imgs[i].height));
			}
		}
	}

	if(!String.isNullOrEmpty(text)) {
		var textBlock = document.createElement('div');
		textBlock.innerHTML = '<p>' + text + '</p>';
		textBlock.querySelector('p').style.color = textColor;
		textBlock.querySelector('p').style.fontSize = fontSize + 'px';
		textBlock.style.textShadow = '0 0 10px black';
		blocks.push(new ElBlock(textBlock, 'center', 'center'));
	}

	var content = document.createElement('div');
	content.style.position = 'relative';

	for(var i = 0; i < blocks.length; ++i) {
		blocks[i].domObject.style.position = 'absolute';
		content.appendChild(blocks[i].domObject);
	}

	var popup = MUIPopover.popover({
		domContent: content,
		backgroundAlpha: backgroundAlpha
	});

	setTimeout(function() {
		for(var i = 0; i < blocks.length; ++i) {
			blocks[i].domObject.style.position = 'absolute';
			content.appendChild(blocks[i].domObject);
			if(blocks[i].width) {
				blocks[i].domObject.style.width = blocks[i].width + 'px';
			}
			if(blocks[i].height) {
				blocks[i].domObject.style.height = blocks[i].height + 'px';
			}
			switch(blocks[i].x) {
				case 'center':
					{
						blocks[i].domObject.style.left = (blocks[i].xOffset + (window.innerWidth - blocks[i].domObject.offsetWidth)) / 2 + 'px';
					}
					break;
				case 'right':
					{
						blocks[i].domObject.style.right = 0;
					}
					break;
				default:
					blocks[i].domObject.style.left = blocks[i].x + 'px';
			}

			switch(blocks[i].y) {
				case 'center':
					{
						blocks[i].domObject.style.top = (blocks[i].yOffset + (window.innerHeight - blocks[i].domObject.offsetHeight) / 2) + 'px';
					}
					break;
				default:
					blocks[i].domObject.style.top = blocks[i].y + 'px';
			}

			blocks[i].domObject.style.removeProperty('visibility');
		}
	}, 100);
}